@@ -11,7 +11,7 @@ __PACKAGE__->config(
     'default_view' => 'TT'
 );
 
-__PACKAGE__->setup( qw(-Debug) );
+__PACKAGE__->setup;
 
 
 1;
\ No newline at end of file
